@@ -24,8 +24,7 @@ static GtkObjectClass *parent_class = NULL;
 
 typedef struct {
 	Bonobo_ConfigDatabase db;
-	char *filter_path;
-	char *append_path;
+	char *path;
 } DataBaseInfo;
 
 struct _BonoboConfigDatabasePrivate {
@@ -312,8 +311,7 @@ impl_Bonobo_ConfigDatabase_removeDir (PortableServer_Servant  servant,
 static void 
 impl_Bonobo_ConfigDatabase_addDatabase (PortableServer_Servant servant,
 					const Bonobo_ConfigDatabase ddb,
-					const CORBA_char  *filter_path,
-					const CORBA_char  *append_path,
+					const CORBA_char  *path,
 					CORBA_Environment *ev)
 {
 	BonoboConfigDatabase *cd = DATABASE_FROM_SERVANT (servant);
@@ -340,8 +338,7 @@ impl_Bonobo_ConfigDatabase_addDatabase (PortableServer_Servant servant,
 		return;
 	}
 	
-	info->filter_path = g_strdup (filter_path);
-	info->append_path = g_strdup (append_path);
+	info->path = g_strdup (path);
 
 	cd->priv->db_list = g_list_append (cd->priv->db_list, info);
 }
@@ -377,11 +374,7 @@ bonobo_config_database_destroy (GtkObject *object)
 
 		bonobo_object_release_unref (info->db, NULL);
 
-		if (info->filter_path)
-			g_free (info->filter_path);
-		
-		if (info->append_path)
-			g_free (info->append_path);
+		g_free (info->path);
 
 		g_free (info);
 	}
